// joi/1/estore/ShoppingCart.java  
//
//
// Copyright 2003 Bill Campbell and Ethan Bolker

/**
 * A ShoppingCart keeps track of a customer's purchases.
 *
 * @see EStore
 * @version 1
 */

public class ShoppingCart
{
    private int count; // number of Items in this ShoppingCart
    private int cost;  // cost of Items in this ShoppingCart
    
    /**
     *  Construct a new empty ShoppingCart.
     */

    public ShoppingCart()
    {
	count = 0;
	cost  = 0;
    }

    /**
     * When this ShoppingCart is asked to add an Item to itself
     * it updates its count field and then updates its cost
     * field by sending the Item a getCost message.
     *
     * @param purchase the Item being added to this ShoppingCart.
     */

    public void add( Item purchase )
    {
	count++; // Java idiom for count = count + 1;
	cost = cost + purchase.getCost();
    }

    /** 
     * What happens when this ShoppingCart is asked how many
     * Items it contains.
     *
     * @return the count of Items.
     */

    public int getCount()
    {
	return count;
    }

    /** 
     * What happens when this ShoppingCart is asked the total
     * cost of the Items it contains.
     *
     * @return the total cost.
     */

    public int getCost()
    {
	return cost;
    }
}
