// joi/1/lights/Lens.java
//
//
// Copyright 2003 Bill Campbell and Ethan Bolker

import java.awt.*;

/**
 * A Lens has a certain color and can either be turned on
 * (the color) or turned off (black).
 *
 * @version 1
 */

public class Lens extends Canvas
{
    private Color onColor;                // color on
    private Color offColor = Color.black; // color off
    private Color currentColor;           // color the lens is now

    private final static int SIZE = 100;  // how big is this Lens?
    private final static int OFFSET = 20; // offset of Lens in Canvas

    /**
     * Construct a Lens to display a given color.
     *
     * The lens is black when it's turned off. 
     *
     * @param color the color of the lens when it is turned on.
     */

    public Lens( Color color )
    {
	this.setBackground( Color.black );
	this.onColor = color;
	this.setSize( SIZE , SIZE );
	this.turnOff();
    }

    /**
     * How this Lens paints itself.
     *
     * @param g a Graphics object to manage brush and color information.
     */
    
    public void paint( Graphics g )
    {
	g.setColor( this.currentColor );
	g.fillOval( OFFSET, OFFSET, 
		    SIZE - OFFSET*2, SIZE - OFFSET*2 );
    }

    /**
     * Have this Lens display its color.
     */

    public void turnOn()
    {
	currentColor = onColor;
	this.repaint();
    }
    
    /**
     * Darken this lens.
     */

    public void turnOff()
    {
	currentColor = offColor;
	this.repaint();
    }
}
