// joi/10/joiapplet/JOIApplet.java
//
//
// Copyright 2003 Bill Campbell and Ethan Bolker

import java.applet.*;
import java.awt.*;
import java.awt.event.*;

/**
 * A JOIPanel displays a button and a message.
 * Pushing the button changes the message.
 *
 * This class provides both the panel and the listener for
 * the button on the panel - a common GUI programming idiom.
 *
 * The panel can be displayed either from an applet
 * in a browser or by the JVM as an application.
 *
 * @version 10
 *
 */

public class JOIApplet extends Applet implements ActionListener
{
    private static final String MESSAGE1 = "Java Outside In";
    private static final String MESSAGE2 = "Java Inside Out";
    private String currentMessage = MESSAGE1; // currently displayed

    private Font font;                // for printing the message
    private Button button;            // for changing messages

    /**
     * Equip this Panel with a Button
     * and an associated ButtonListener, and
     * set the font for the message.
     */

    public void init()
    {
        // what this Panel looks like 
        button = new Button( "Press Me" );
        this.add( button );
        font = new Font("Garamond", Font.BOLD, 48);

        // how this Panel behaves
        button.addActionListener( this );
    }

    /**
     * Defines the ActionListener behavior that must be 
     * implemented.
     *
     * When a user pushes the Button that we're listening to, 
     * send a changeMessage() message to the Panel.
     *
     * @param e the "event" when the button is pressed.
     */

    public void actionPerformed( ActionEvent e )
    {
        currentMessage = 
            currentMessage.equals(MESSAGE1) ? MESSAGE2 : MESSAGE1;
        this.repaint();
    }

    /**
     * Draw the current message on this Panel.
     *
     * (The button is already there.)
     *
     * @param g an object encapsulating the graphics (e.g. pen)
     *          properties.
     */

    public void paint(Graphics g) 
    {
        g.setColor(Color.black);
        g.setFont(font);
        g.drawString(currentMessage, 40, 75);
    }

    /**
     * Ask the JVM to display this Panel.
     */

    public static void main( String[] args )
    {
        Terminal t     = new Terminal();
        Frame frame    = new Frame();
        JOIApplet panel = new JOIApplet();
        panel.init();
        frame.add(panel);
        frame.setSize(400,120);
        frame.show();
        t.readLine("Type return to close the window ... ");
        System.exit(0);
    }
}
