// joi/10/juno/JunoTerminal.java 
//
//
// Copyright 2003 Bill Campbell and Ethan Bolker

/**
 * A Command line interface terminal for Juno.
 *
 * @version 10
 */

public class JunoTerminal
    implements InputInterface, OutputInterface
{
    private Terminal terminal; // the delegate terminal
    private boolean  echo;     // are we echoing input?

    /**
     * Construct a JunoTerminal
     *
     * Allows for input echo, when, for example, input is redirected
     * from a file.
     *
     * @param echo whether or not input should be echoed.
     */

    public JunoTerminal( boolean echo )
    {
	this.echo = echo;
	terminal = new Terminal( echo );
    }

    // Implement InputInterface

   /**
    * Read a line (terminated by a newline).
    *
    * @param promptString output string to prompt for input
    * @return the string (without the newline character)
    */

    public String readLine( String promptString )
    {
	return terminal.readLine( promptString );
    }

    // Implement OutputInterface

   /**
     * Write a String followed by a newline
     * to console output location.
     *
     * @param str - the string to write
     */

    public void println(String str )
    {
	terminal.println( str );
    }

    /**
     * Write a String followed by a newline
     * to console error output location.
     *
     * @param str - the String to write
     */

    public void errPrintln(String str )
    {
	terminal.errPrintln( str );
    }

    /**
     * Query what kind of console this is.
     *
     * @return true if and only if echoing input.
     */

    public boolean isEchoInput() 
    {
	return echo;
    }
   
    /**
     * Query what kind of console this is.
     *
     * @return false, since it is not a GUI
     */

    public boolean isGUI() 
    {
	return false;
    }
    
    /**
     * Query what kind of console this is.
     *
     * @return false, since it is not remote.
     */

    public boolean isRemote() 
    {
	return false;
    }
}
