// joi/10/juno/TypeCommand.java
//
//
// Copyright 2003, Bill Campbell and Ethan Bolker

import java.util.*;

/**
 * The Juno shell command to display the contents of a 
 * text file.
 * Usage:
 * <pre>
 *     type textfile
 * </pre>
 *
 * @version 10
 */

public class TypeCommand extends ShellCommand 
{
    TypeCommand() 
    {
        super( "display contents of a TextFile", "textfile" );
    }

    /**
     * Display the contents of a TextFile.
     *
     * @param args the remainder of the command line.
     * @param sh the current Shell
     *
     * @exception JunoException for reporting errors
     */

    public void doIt( StringTokenizer args, Shell sh )
	throws JunoException                               
    {
        String filename;
        try {                                              
            filename = args.nextToken();
        }                                                  
        catch (NoSuchElementException e) {
            throw new BadShellCommandException( this );    
        }                                                  
        try {                                              
            sh.getConsole().println( 
                ( (TextFile) sh.getDot().
                  retrieveJFile( filename ) ).getContents() );
        }                                                  
        catch (NullPointerException e) {                   
            throw new JunoException( "JFile does not exist: "  
                                     + filename);              
        }                                                      
        catch (ClassCastException e) {                         
            throw new JunoException( "JFile not a text file: " 
                                     + filename);              
        }                                                      
    }
}
