// joi/4/dictionary/Dictionary.java
//
//
// Copyright 2003 Bill Campbell and Ethan Bolker

import java.util.*;

/**
 * Model a dictionary with a TreeMap of (word, Definition) pairs.
 *
 * @see Definition
 *
 * @version 4
 */

public class Dictionary
{
    private TreeMap entries;

    /**
     * Construct an empty Dictionary.
     */

    public Dictionary() 
    {
        entries = new TreeMap();
    }

    /** 
     * Add an entry to this Dictionary.
     *
     * @param word the word being defined.
     * @param definition the Definition of that word.
     */

    public void addEntry( String word, Definition definition ) 
    {
        entries.put( word, definition );
    }

    /**
     * Look up an entry in this Dictionary.
     *
     * @param word the word whose definition is sought
     * @return the Definition of that word, null if none.
     */

    public Definition getEntry( String word ) 
    {
        return (Definition)entries.get(word);
    }

    /**
     * Get the size of this Dictionary.
     *
     * @return the number of words.
     */
    
    public int getSize() 
    {
        return entries.size();
    }

    /**
     * Construct a String representation of this Dictionary. 
     *
     * @return a multiline String representation.
     */

    public String toString()
    {
        String str = "";
        String word;
        Definition definition;
        Set allWords = entries.keySet();
        Iterator wordIterator = allWords.iterator();
        while ( wordIterator.hasNext() ) {
            word = (String)wordIterator.next();
            definition = this.getEntry( word );
            str += word + ":\n" + definition.toString() + "\n";
        }
        return str;
    }
}
