// joi/4/dictionary/Lookup.java

//

//

// Copyright 2003 Bill Campbell and Ethan Bolker



/**

 * On line word lookup.

 *

* @see Dictionary

 * @see Definition

 *

 * @version 4

 */



public class Lookup

{

    private static Terminal t = new Terminal();

    private static Dictionary dictionary = new Dictionary();



    /**

     * Helper method to fill the dictionary with some simple

     * Definitions.

     *

     * A real Dictionary would live in a file somewhere.

     */



    private static void fillDictionary()

    {

        dictionary.addEntry( "shape",

            new Definition(  "a geometric object in a plane" ) );

        dictionary.addEntry( "quadrilateral",

            new Definition(  "a polygonal shape with four sides" ) );

        dictionary.addEntry( "rectangle",

            new Definition(  "a right-angled quadrilateral" ) );

        dictionary.addEntry( "square",

            new Definition(  "a rectangle having equal sides" ) );

    }



    /**

     * Helper method to print the Definition of a single word,

     * or a message if the word is not in the Dictionary.

     *

     * @param word the word whose definition is wanted.

     */



    private static void printDefinition(String word)

    {

        Definition definition = dictionary.getEntry(word);

        if (definition == null) {

            t.println("sorry, no definition found for " + word);

        }

        else {

            t.println(definition.toString());

        }

    }



    /**

     * Run the Dictionary lookup. 

     *

     * Parse command line arguments for words to look up,

     * "all" prints the whole Dictionary.

     *

     * Then prompt for more words, "quit" to finish.

     *

     * For example,

     * <pre>

     *

     * %> java Lookup shape square circle

     * shape:

     * a geometric object in a plane

     * square:

     * a rectangle having equal sides

     * circle:

     * sorry, no definition found for circle

     * 

     * look up words, "quit" to quit

     * word> rectangle

     * a right-angled quadrilateral

     * word> quit

     * %>

     * </pre>

     *

     * @param args the words that we want looked up, supplied as

     *             command line arguments.  If the word "all" is

     *             included, all words are looked up.

     */



    public static void main( String[] args )

    {

        // fill the dictionary (not a big one!)

        fillDictionary();

        

        // look up some words 

        String word;



        // words specified on command line

        for (int i = 0; i < args.length; i++ ) {

            word = args[i];

            if (word.equals("all")) {

                t.println("The whole dictionary (" + 

                          dictionary.getSize() + " entries):");

                t.println("-------------------");

                t.println(dictionary.toString());

                t.println("-------------------");

            }

            else {

                t.println(word + ":");

                printDefinition(word);

            }

        }



        // words entered interactively

        t.println("\nlook up words, \"quit\" to quit");

        while (true) {

            word = t.readWord("word> ");

            if (word.equals("quit")) {

                break;

            }

            printDefinition(word);

        }

    }

}

