// joi/5/bank/CheckingAccount.java
//
//
// Copyright 2003 Bill Campbell and Ethan Bolker

/**
 * A CheckingAccount is a BankAccount with one new feature:
 * the ability to cash a check by calling the honorCheck method.
 * Each honored check costs the customer a checkFee.
 *
 * @version 5
 */ 

public class CheckingAccount extends BankAccount 
{
    private static int checkFee = 2;  // pretty steep for each check

    /**
     * Constructs a CheckingAccount with the given
     * initial balance and issuing Bank.
     * Counts as this account's first transaction.
     *
     * @param initialBalance the opening balance for this account.
     * @param issuingBank the bank that issued this account.
     */

    public CheckingAccount( int initialBalance, Bank issuingBank ) 
    {
        super( initialBalance, issuingBank );
    }

    /**
     * Honor a check:
     * Charge the account the appropriate fee
     * and withdraw the amount.
     *
     * @param amount amount (in whole dollars) to be withdrawn.
     * @return the amount withdrawn.     
     */

    public int honorCheck( int amount )  
    {
        incrementBalance( - checkFee );
        return withdraw( amount );
    }

    /**
     * Action to take when a new month starts.
     */

    public void newMonth()
    {
    }
}
