// joi/5/shapes/Screen.java
//
//
// Copyright 1998-2001 Bill Campbell and Ethan Bolker

/**
 * A Screen is a (width*height) grid of (character) 'pixels'
 * on which we may paint various shapes.  It can be drawn to
 * a Terminal.
 *
 * @version 5
 */

public class Screen
{
    private static final char FRAMECHAR = '+';
    private static final char BLANK = ' ';
    private int       width;
    private int       height;
    private char[][] pixels;
   
    /** 
     * Construct a screen.
     *
     * @param width the number of pixels in the x direction.
     * @param height the number of pixels in the y direction.
     */

    public Screen( int width, int height )
    {
        this.width  = width;
        this.height = height;
        pixels = new char[width][height];
        clear();
    }

    /**
     * Clear the Screen, painting a blank at every pixel.
     */
    
    public void clear()
    {
        for (int x  = 0; x < width; x++)
            for ( int y = 0; y < height; y++ )
                pixels[x][y] = BLANK;
    }

    /**
     * Paint a character pixel at position (x,y).
     *
     * @param c the character to be painted.
     * @param x the (horizontal) x position.
     * @param y the (vertical) y position.
     */

    public void paintAt( char c, int x, int y )
    {
        if ( 0 <= x && x < width &&
             0 <= y && y < height)
            pixels[x][y] = c;
        // otherwise off the Screen - nothing is painted
    }
    
    /**
     * Draw this Screen on a Terminal.
     *
     * @param t the Terminal on which to draw this Screen.
     */

    public void draw( Terminal t )
    {
        for ( int col = -1; col < width+1 ; col++ )  // top edge
            t.print(FRAMECHAR);        
        t.println();                               
        for ( int row = 0; row < height; row++ ) {  
            t.print(FRAMECHAR);                      // left edge
            for ( int col = 0; col < width; col++ )
                t.print( pixels[col][row] );
            t.println( FRAMECHAR );                  // right edge
        }
        for ( int col = -1; col < width+1 ; col++ )  // bottom edge
            t.print(FRAMECHAR);
        t.println();
    }
}
