// joi/5/shapes/VLine.java
//
//
// Copyright 2003 Bill Campbell and Ethan Bolker

/**
 * A VLine is a vertical Line.
 */

public class VLine extends Line
{
    /**
     * Construct a VLine having a paintChar and a length.
     *
     * @param length length in (character) pixels.
     * @param paintChar character used for painting this Line.
     */

    public VLine( int length, char paintChar )
    {
        super( length, paintChar );
    }

    /**
     * Paint this Line on Screen s at position (x,y).
     *
     * @param screen the Screen on which this Line is to be painted.
     * @param x      the x position for the line.
     * @param y      the y position for the line.
     */

    public void paintOn( Screen screen, int x, int y )
    {
        for ( int i = 0; i < length; i++ )
            screen.paintAt( paintChar, x, y+i );
    }

    /**
     * Unit test for class VLine. 
     */

    public static void main( String[] argv )
    {
        Terminal terminal = new Terminal();

        terminal.println( "Self documenting unit test of VLine.");
        terminal.println( "The two Screens that follow should match.");
        terminal.println();
        terminal.println( "Hard coded picture:");
        terminal.println( "+++++++++");
        terminal.println( "+xx     +");
        terminal.println( "+xx     +");
        terminal.println( "+xx     +");
        terminal.println( "+xx *   +");
        terminal.println( "+xx *1  +");
        terminal.println( "+x  *   +");
        terminal.println( "+x  *   +");
        terminal.println( "+   *   +");
        terminal.println( "+       +");
        terminal.println( "+++++++++");
        terminal.println();

        terminal.println( "Picture drawn using VLine methods:");
        Screen screen = new Screen( 7,  9 );

        Line vLine = new VLine(  7, 'x' );
        vLine.paintOn( screen );

        vLine.setLength(5);
        vLine.paintOn( screen, 1, 0 );

        vLine.setPaintChar('*');
        vLine.paintOn( screen, 3, 3 );
        
        vLine.setLength(1);
        vLine.setPaintChar('1');
        vLine.paintOn( screen, 4, 4 );

        screen.draw( terminal );
    }

}
