// joi/6/juno/ShellCommandTable.java (version 6)
//
//
// Copyright 2003 Bill Campbell and Ethan Bolker

import java.util.*;

/**
 * A ShellCommandTable object maintains a dispatch table of 
 * ShellCommand objects keyed by the command names used to invoke 
 * them.
 *
 * To add a new shell command to the table, install it from 
 * method fillTable().
 *
 * @see ShellCommand
 *
 * @version 6
 */

public class ShellCommandTable 
{
    private Map table = new TreeMap(); 
    
    /**
     * Construct and fill a shell command table.
     */

    public ShellCommandTable()
    {
        fillTable();
    }

    /**
     * Get a ShellCommand, given the command name key.
     *
     * @param key the name associated with the command we're
     *            looking for.
     *
     * @return the command we're looking for, null if none.
     */

    public ShellCommand lookup( String key ) 
    {
        return (ShellCommand)table.get( key );
    }

    /**
     * Get an array of the command names.
     *
     * @return the array of command names.
     */

    public String[] getCommandNames() 
    {
        return (String[]) table.keySet().toArray( new String[0] );
    }

    // Associate a command name with a ShellCommand.

    private void install( String commandName, ShellCommand command )
    {
        table.put( commandName, command );
    }

    // Fill the dispatch table with ShellCommands, keyed by their 
    // command names.

    private void fillTable() 
    {
        install( "newfile", new NewfileCommand() );
        install( "type", new TypeCommand() );
        install( "mkdir", new MkdirCommand() );
        install( "help", new HelpCommand() );
    }
}
